==> oeshop_0.03.tar.gz: oeshop/admin/prize_admin/php/prize_edit.php <==
<?php
//require_once("../../admin_auth.php");
if (file_exists("../../../lib/connect.php")) { require_once("../../../lib/connect.php"); }
require_once("../../lib/prize_lib.php");

if (empty($HTTP_POST_VARS[id])) {
	echo ("ǰID Է ֽʽÿ!");
	exit;
}
else {
	$t_id = $HTTP_POST_VARS[id];
	$row = read_prize($HTTP_POST_VARS[id], $db_conn);

	// ̹ ɼǼ
	$t_img = explode("@", $row[img_option]);
	$i = 0;
	foreach ($t_img as $temp) {
		$img_option[$i] = explode(":", $temp);
		$i++;
	}
}

// POST  ˻
if (empty($HTTP_POST_VARS[category_code])) { err_msg("зڵ带 Է ֽʽÿ."); exit; }
else { $t_category_code = $HTTP_POST_VARS[category_code]; }

if (empty($HTTP_POST_VARS[prize_num])) { err_msg("ǰȣ Է ֽʽÿ."); exit; }
else { $t_prize_num = $HTTP_POST_VARS[prize_num]; }

if (empty($HTTP_POST_VARS[prize_sail1])) { err_msg("Һڰ Է ֽʽÿ."); exit; }
else { $t_prize_sail1 = $HTTP_POST_VARS[prize_sail1]; }

if (empty($HTTP_POST_VARS[prize_sail2])) { err_msg("ǸŰ Է ֽʽÿ."); exit; }
else { $t_prize_sail2 = $HTTP_POST_VARS[prize_sail2]; }

if (empty($HTTP_POST_VARS[prize_point])) { err_msg("Ʈ Է ֽʽÿ."); exit; }
else { $t_prize_point = $HTTP_POST_VARS[prize_point]; }

if (empty($HTTP_POST_VARS[prize_amount])) { err_msg("ǰ Է ֽʽÿ."); exit; }
else { $t_prize_amount = $HTTP_POST_VARS[prize_amount]; }

if ($view_img == "none") { $t_view_img = $row[view_img]; }
else {
	if (!file_exists($view_img)) {
		echo ("
			̹  Ͽϴ.<br>
			".$view_img
		);
		exit;
	}
	else {
		$temp_img = explode(".", $view_img_name);
		$temp_tot = sizeof($temp_img);
		$ext = $temp_img[$temp_tot - 1];
		$target = "\"../../../pds/shop_img/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
		$del_target = "\"../../../pds/shop_img/".$row[view_img]."\"";

		@unlink($del_target);
		if (@exec("mv ".$view_img." ".$target)) {
			echo ("
				̹  űⰡ Ͽϴ.<br>
				$target
			");
			exit;
		}

		$t_view_img = $HTTP_POST_VARS[prize_num].".".$ext;
	}
}

if (empty($HTTP_POST_VARS[prize_name])) { err_msg("ǰ Է ֽʽÿ."); exit; }
else { $t_prize_name = $HTTP_POST_VARS[prize_name]; }

if (empty($HTTP_POST_VARS[option1])) { $t_option1 = "N/A"; }
else { $t_option1 = $HTTP_POST_VARS[option1]; }

if (empty($HTTP_POST_VARS[option2])) { $t_option2 = "N/A"; }
else { $t_option2 = $HTTP_POST_VARS[option2]; }

if (empty($HTTP_POST_VARS[option13])) { $t_option3 = "N/A"; }
else { $t_option3 = $HTTP_POST_VARS[option3]; }

if (empty($HTTP_POST_VARS[option_val1])) { $t_option_val1 = "N/A"; }
else { $t_option_val1 = $HTTP_POST_VARS[option_val1]; }

if (empty($HTTP_POST_VARS[option_val2])) { $t_option_val2 = "N/A"; }
else { $t_option_val2 = $HTTP_POST_VARS[option_val2]; }

if (empty($HTTP_POST_VARS[option_val3])) { $t_option_val3 = "N/A"; }
else { $t_option_val3 = $HTTP_POST_VARS[option_val3]; }

// ̹ ɼ
$t_img_option = "";

if (empty($HTTP_POST_VARS[img_option1])) { $t_img_option = ":@"; }
else {
	if ($img_option_v1 == "none") {
		if ($HTTP_POST_VARS[action] == "edit") { $t_img_option_v1 = $img_option[0][1]; }
	}
	else {
		if (!file_exists($img_option_v1)) {
			echo ("
				ɼ1 ̹  Ͽϴ.<br>
				".$img_option_v1
			);
			exit;
		}
		else {
			$temp_img = explode(".", $img_option_v1_name);
			$temp_tot = sizeof($temp_img);
			$ext = $temp_img[$temp_tot - 1];
			$target = "\"../../../pds/option1/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
			$del_target = "\"../../../pds/option1/".$img_option[0][1]."\"";

			@unlink($del_target);
			if (@exec("mv ".$img_option_v1." ".$target)) {
				echo ("
					ɼ1 ̹  űⰡ Ͽϴ.<br>
					$target
				");
				exit;
			}

			$t_img_option_v1 = $HTTP_POST_VARS[prize_num].".".$ext;
		}
	}
	$t_img_option = $HTTP_POST_VARS[img_option1].":".$t_img_option_v1."@";
}

if (empty($HTTP_POST_VARS[img_option2])) { $t_img_option .= ":@"; }
else {
	if ($img_option_v2 == "none") { $t_img_option_v2 = $img_option[1][1]; }
	else {
		if (!file_exists($img_option_v2)) {
			echo ("
				ɼ2 ̹  Ͽϴ.<br>
				".$img_option_v2
			);
			exit;
		}
		else {
			$temp_img = explode(".", $img_option_v2_name);
			$temp_tot = sizeof($temp_img);
			$ext = $temp_img[$temp_tot - 1];
			$target = "\"../../../pds/option2/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
			$del_target = "\"../../../pds/option2/".$img_option[1][1]."\"";

			@unlink($del_target);
			if (@exec("mv ".$img_option_v2." ".$target)) {
				echo ("
					ɼ2 ̹  űⰡ Ͽϴ.<br>
					$target
				");
				exit;
			}

			$t_img_option_v2 = $HTTP_POST_VARS[prize_num].".".$ext;
		}
	}
	$t_img_option .= $HTTP_POST_VARS[img_option2].":".$t_img_option_v2."@";
}

if (empty($HTTP_POST_VARS[img_option3])) { $t_img_option .= ":@"; }
else {
	if ($img_option_v3 == "none") { $t_img_option_v3 = $img_option[2][1]; }
	else {
		if (!file_exists($img_option_v3)) {
			echo ("
				ɼ3 ̹  Ͽϴ.<br>
				".$img_option_v3
			);
			exit;
		}
		else {
			$temp_img = explode(".", $img_option_v3_name);
			$temp_tot = sizeof($temp_img);
			$ext = $temp_img[$temp_tot - 1];
			$target = "\"../../../pds/option3/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
			$del_target = "\"../../../pds/option3/".$img_option[2][1]."\"";

			@unlink($del_target);
			if (@exec("mv ".$img_option_v3." ".$target)) {
				echo ("
					ɼ3 ̹  űⰡ Ͽϴ.<br>
					$target
				");
				exit;
			}

			$t_img_option_v3 = $HTTP_POST_VARS[prize_num].".".$ext;
		}
	}
	$t_img_option .= $HTTP_POST_VARS[img_option3].":".$t_img_option_v3."@";
}

if (empty($HTTP_POST_VARS[img_option4])) { $t_img_option .= ":@"; }
else {
	if ($img_option_v4 == "none") { $t_img_option_v4 = $img_option[3][1]; }
	else {
		if (!file_exists($img_option_v4)) {
			echo ("
				ɼ4 ̹  Ͽϴ.<br>
				".$img_option_v4
			);
			exit;
		}
		else {
			$temp_img = explode(".", $img_option_v4_name);
			$temp_tot = sizeof($temp_img);
			$ext = $temp_img[$temp_tot - 1];
			$target = "\"../../../pds/option4/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
			$del_target = "\"../../../pds/option4/".$img_option[3][1]."\"";

			@unlink($del_target);
			if (@exec("mv ".$img_option_v4." ".$target)) {
				echo ("
					ɼ4 ̹  űⰡ Ͽϴ.<br>
					$target
				");
				exit;
			}

			$t_img_option_v4 = $HTTP_POST_VARS[prize_num].".".$ext;
		}
	}
	$t_img_option .= $HTTP_POST_VARS[img_option4].":".$t_img_option_v4."@";
}

if (empty($HTTP_POST_VARS[img_option5])) { $t_img_option .= ":"; }
else {
	if ($img_option_v5 == "none") { $t_img_option_v5 = $img_option[4][1]; }
	else {
		if (!file_exists($img_option_v5)) {
			echo ("
				ɼ5 ̹  Ͽϴ.<br>
				".$img_option_v5
			);
			exit;
		}
		else {
			$temp_img = explode(".", $img_option_v5_name);
			$temp_tot = sizeof($temp_img);
			$ext = $temp_img[$temp_tot - 1];
			$target = "\"../../../pds/option5/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
			$del_target = "\"../../../pds/option5/".$img_option[4][1]."\"";

			@unlink($del_target);
			if (@exec("mv ".$img_option_v5." ".$target)) {
				echo ("
					ɼ5 ̹  űⰡ Ͽϴ.<br>
					$target
				");
				exit;
			}

			$t_img_option_v5 = $HTTP_POST_VARS[prize_num].".".$ext;
		}
	}
	$t_img_option .= $HTTP_POST_VARS[img_option5].":".$t_img_option_v5."@";
}

// Ÿɼ
if (empty($HTTP_POST_VARS[prize_view])) { $t_prize_view = "N"; }
else { $t_prize_view = "Y"; }

if (empty($HTTP_POST_VARS[prize_recommand])) { $t_prize_recommand = "N"; }
else { $t_prize_recommand = "Y"; }

if (empty($HTTP_POST_VARS[prize_popular])) { $t_prize_popular = "N"; }
else { $t_prize_popular = "Y"; }

if (empty($HTTP_POST_VARS[prize_new])) { $t_prize_new = "N"; }
else { $t_prize_new = "Y"; }

if (empty($HTTP_POST_VARS[prize_mrecommand])) { $t_prize_mrecommand = "N"; }
else { $t_prize_mrecommand = "Y"; }

if (empty($HTTP_POST_VARS[prize_mpopular])) { $t_prize_mpopular = "N"; }
else { $t_prize_mpopular = "Y"; }

if (empty($HTTP_POST_VARS[prize_mnew])) { $t_prize_mnew = "N"; }
else { $t_prize_mnew = "Y"; }

$t_body = $HTTP_POST_VARS[body];
$remote_ip = $HTTP_REMOTE_ADDR;
$regdate = date("Y-m-d");

//  ۼ
if ($HTTP_POST_VARS[action] == "edit") {
	$query = "UPDATE shop_prize SET ";
	$query .= "category_code='$t_category_code', prize_num='$t_prize_num', prize_sail1='$t_prize_sail1', prize_sail2='$t_prize_sail2', prize_point='$t_prize_point', prize_amount='$t_prize_amount', ";
	$query .= "view_img='$t_view_img', prize_name='$t_prize_name', option1='$t_option1', option2='$t_option2', option3='$t_option3', option_val1='$t_option_val1', option_val2='$t_option_val2', option_val3='$t_option_val3', ";
	$query .= "img_option='$t_img_option', body='$t_body', prize_view='$t_prize_view', prize_recommand='$t_prize_recommand', prize_popular='$t_prize_popular', prize_new='$t_prize_new', prize_mrecommand='$t_prize_mrecommand', ";
	$query .= "prize_mpopular='$t_prize_mpopular', prize_mnew='$t_prize_mnew', remote_ip='$remote_ip', count='0', regdate='$regdate' ";
	$query .= "WHERE id='$t_id'";
}
elseif ($HTTP_POST_VARS[action] == "add") {
}

//  
if (!mysql_query($query, $db_conn)) {
	echo " Ȥ DB  ֽϴ.<br>";
	echo $query."<br><br>";
	echo mysql_error();
	exit;
}
else {
	echo "<meta http-equiv='refresh' content='0;url=../prize_list.php?category_code=$t_category_code&page=".$HTTP_POST_VARS[page]."&scale=".$HTTP_POST_VARS[scale]."&search_item=".$HTTP_POST_VARS[search_item]."&search_val=".$HTTP_POST_VARS[search_val]."'>";
}
?>

==> oeshop_0.07.tar.gz: oeshop/admin/prize_admin/php/prize_edit.php <==
<?php
//require_once("../../admin_auth.php");
if (file_exists("../../../lib/connect.php")) { require_once("../../../lib/connect.php"); }
require_once("../../lib/prize_lib.php");

if (empty($HTTP_POST_VARS[cur_prize_num]) && $HTTP_POST_VARS[action] == "edit") {
	echo ("ǰID Է ֽʽÿ!");
	exit;
}
elseif ($HTTP_POST_VARS[action] == "edit") {
	$t_id = $HTTP_POST_VARS[id];
	$row = read_prize($HTTP_POST_VARS[id], $db_conn);

	// ̹ ɼǼ
	$t_img = explode("@", $row[img_option]);
	$i = 0;
	foreach ($t_img as $temp) {
		$img_option[$i] = explode(":", $temp);
		$i++;
	}
}

// POST  ˻
if (empty($HTTP_POST_VARS[category_code])) { err_msg("зڵ带 Է ֽʽÿ."); exit; }
else { $t_category_code = $HTTP_POST_VARS[category_code]; }

if (empty($HTTP_POST_VARS[prize_num])) { err_msg("ǰȣ Է ֽʽÿ."); exit; }
else { $t_prize_num = $HTTP_POST_VARS[prize_num]; }

if (empty($HTTP_POST_VARS[prize_sail1])) { err_msg("Һڰ Է ֽʽÿ."); exit; }
else { $t_prize_sail1 = $HTTP_POST_VARS[prize_sail1]; }

if (empty($HTTP_POST_VARS[prize_sail2])) { err_msg("ǸŰ Է ֽʽÿ."); exit; }
else { $t_prize_sail2 = $HTTP_POST_VARS[prize_sail2]; }

if (empty($HTTP_POST_VARS[prize_point])) { err_msg("Ʈ Է ֽʽÿ."); exit; }
else { $t_prize_point = $HTTP_POST_VARS[prize_point]; }

if (empty($HTTP_POST_VARS[prize_amount])) { err_msg("ǰ Է ֽʽÿ."); exit; }
else { $t_prize_amount = $HTTP_POST_VARS[prize_amount]; }

if ($HTTP_POST_FILES[view_img][size] <= 0) { $t_view_img = $row[view_img]; }
else {
	if (!file_exists($HTTP_POST_FILES[view_img][tmp_name])) {
		echo ("
			̹  Ͽϴ...<br>
			".$HTTP_POST_FILES[view_img][name]
		);
		exit;
	}
	else {
		$temp_img = explode(".", $HTTP_POST_FILES[view_img][name]);
		$temp_tot = sizeof($temp_img);
		$ext = $temp_img[$temp_tot - 1];
		$target = "\"../../../pds/shop_img/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
		$del_target = "\"../../../pds/shop_img/".$row[view_img]."\"";

		@unlink($del_target);
		if (@exec("mv ".$HTTP_POST_FILES[view_img][tmp_name]." ".$target)) {
			echo ("
				̹  űⰡ Ͽϴ.<br>
				$target
			");
			exit;
		}

		$t_view_img = $HTTP_POST_VARS[prize_num].".".$ext;
	}
}

if (empty($HTTP_POST_VARS[prize_name])) { err_msg("ǰ Է ֽʽÿ."); exit; }
else { $t_prize_name = $HTTP_POST_VARS[prize_name]; }

if (!empty($HTTP_POST_VARS[option1])) { $t_option1 = $HTTP_POST_VARS[option1]; }
if (!empty($HTTP_POST_VARS[option2])) { $t_option2 = $HTTP_POST_VARS[option2]; }
if (!empty($HTTP_POST_VARS[option3])) { $t_option3 = $HTTP_POST_VARS[option3]; }
if (!empty($HTTP_POST_VARS[option_val1])) { $t_option_val1 = $HTTP_POST_VARS[option_val1]; }
if (!empty($HTTP_POST_VARS[option_val2])) { $t_option_val2 = $HTTP_POST_VARS[option_val2]; }
if (!empty($HTTP_POST_VARS[option_val3])) { $t_option_val3 = $HTTP_POST_VARS[option_val3]; }

// ̹ ɼ
$t_img_option = "";

if (empty($HTTP_POST_VARS[img_option1])) { $t_img_option = ":@"; }
else {
	if ($HTTP_POST_FILES[img_option_v1][size] <= 0) {
		if ($HTTP_POST_VARS[action] == "edit") { $t_img_option_v1 = $img_option[0][1]; }
	}
	else {
		if (!file_exists($HTTP_POST_FILES[img_option_v1][tmp_name])) {
			echo ("
				ɼ1 ̹  Ͽϴ.<br>
				".$HTTP_POST_FILES[img_option_v1][name]
			);
			exit;
		}
		else {
			$temp_img = explode(".", $HTTP_POST_FILES[img_option_v1][name]);
			$temp_tot = sizeof($temp_img);
			$ext = $temp_img[$temp_tot - 1];
			$target = "\"../../../pds/option1/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
			$del_target = "\"../../../pds/option1/".$img_option[0][1]."\"";

			@unlink($del_target);
			if (@exec("mv ".$HTTP_POST_FILES[img_option_v1][tmp_name]." ".$target)) {
				echo ("
					ɼ1 ̹  űⰡ Ͽϴ.<br>
					$target
				");
				exit;
			}

			$t_img_option_v1 = $HTTP_POST_VARS[prize_num].".".$ext;
		}
	}
	$t_img_option = $HTTP_POST_VARS[img_option1].":".$t_img_option_v1."@";
}

if (empty($HTTP_POST_VARS[img_option2])) { $t_img_option .= ":@"; }
else {
	if ($HTTP_POST_FILES[img_option_v2][size] <= 0) {
		if ($HTTP_POST_VARS[action] == "edit") { $t_img_option_v2 = $img_option[1][1]; }
	}
	else {
		if (!file_exists($HTTP_POST_FILES[img_option_v2][tmp_name])) {
			echo ("
				ɼ1 ̹  Ͽϴ.<br>
				".$HTTP_POST_FILES[img_option_v2][name]
			);
			exit;
		}
		else {
			$temp_img = explode(".", $HTTP_POST_FILES[img_option_v2][name]);
			$temp_tot = sizeof($temp_img);
			$ext = $temp_img[$temp_tot - 1];
			$target = "\"../../../pds/option2/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
			$del_target = "\"../../../pds/option2/".$img_option[1][1]."\"";

			@unlink($del_target);
			if (@exec("mv ".$HTTP_POST_FILES[img_option_v2][tmp_name]." ".$target)) {
				echo ("
					ɼ2 ̹  űⰡ Ͽϴ.<br>
					$target
				");
				exit;
			}

			$t_img_option_v2 = $HTTP_POST_VARS[prize_num].".".$ext;
		}
	}
	$t_img_option .= $HTTP_POST_VARS[img_option2].":".$t_img_option_v2."@";
}

if (empty($HTTP_POST_VARS[img_option3])) { $t_img_option .= ":@"; }
else {
	if ($HTTP_POST_FILES[img_option_v3][size] <= 0) {
		if ($HTTP_POST_VARS[action] == "edit") { $t_img_option_v1 = $img_option[2][1]; }
	}
	else {
		if (!file_exists($HTTP_POST_FILES[img_option_v3][tmp_name])) {
			echo ("
				ɼ3 ̹  Ͽϴ.<br>
				".$HTTP_POST_FILES[img_option_v3][name]
			);
			exit;
		}
		else {
			$temp_img = explode(".", $HTTP_POST_FILES[img_option_v3][name]);
			$temp_tot = sizeof($temp_img);
			$ext = $temp_img[$temp_tot - 1];
			$target = "\"../../../pds/option3/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
			$del_target = "\"../../../pds/option3/".$img_option[2][1]."\"";

			@unlink($del_target);
			if (@exec("mv ".$HTTP_POST_FILES[img_option_v3][tmp_name]." ".$target)) {
				echo ("
					ɼ3 ̹  űⰡ Ͽϴ.<br>
					$target
				");
				exit;
			}

			$t_img_option_v3 = $HTTP_POST_VARS[prize_num].".".$ext;
		}
	}
	$t_img_option .= $HTTP_POST_VARS[img_option3].":".$t_img_option_v3."@";
}

if (empty($HTTP_POST_VARS[img_option4])) { $t_img_option .= ":@"; }
else {
	if ($HTTP_POST_FILES[img_option_v4][size] <= 0) {
		if ($HTTP_POST_VARS[action] == "edit") { $t_img_option_v4 = $img_option[3][1]; }
	}
	else {
		if (!file_exists($HTTP_POST_FILES[img_option_v4][tmp_name])) {
			echo ("
				ɼ4 ̹  Ͽϴ.<br>
				".$HTTP_POST_FILES[img_option_v4][name]
			);
			exit;
		}
		else {
			$temp_img = explode(".", $HTTP_POST_FILES[img_option_v4][name]);
			$temp_tot = sizeof($temp_img);
			$ext = $temp_img[$temp_tot - 1];
			$target = "\"../../../pds/option4/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
			$del_target = "\"../../../pds/option4/".$img_option[3][1]."\"";

			@unlink($del_target);
			if (@exec("mv ".$HTTP_POST_FILES[img_option_v4][tmp_name]." ".$target)) {
				echo ("
					ɼ4 ̹  űⰡ Ͽϴ.<br>
					$target
				");
				exit;
			}

			$t_img_option_v4 = $HTTP_POST_VARS[prize_num].".".$ext;
		}
	}
	$t_img_option .= $HTTP_POST_VARS[img_option4].":".$t_img_option_v4."@";
}

if (empty($HTTP_POST_VARS[img_option5])) { $t_img_option .= ":@"; }
else {
	if ($HTTP_POST_FILES[img_option_v5][size] <= 0) {
		if ($HTTP_POST_VARS[action] == "edit") { $t_img_option_v5 = $img_option[4][1]; }
	}
	else {
		if (!file_exists($HTTP_POST_FILES[img_option_v5][tmp_name])) {
			echo ("
				ɼ1 ̹  Ͽϴ.<br>
				".$HTTP_POST_FILES[img_option_v5][name]
			);
			exit;
		}
		else {
			$temp_img = explode(".", $HTTP_POST_FILES[img_option_v5][name]);
			$temp_tot = sizeof($temp_img);
			$ext = $temp_img[$temp_tot - 1];
			$target = "\"../../../pds/option5/".$HTTP_POST_VARS[prize_num].".".$ext."\"";
			$del_target = "\"../../../pds/option5/".$img_option[4][1]."\"";

			@unlink($del_target);
			if (@exec("mv ".$HTTP_POST_FILES[img_option_v5][tmp_name]." ".$target)) {
				echo ("
					ɼ1 ̹  űⰡ Ͽϴ.<br>
					$target
				");
				exit;
			}

			$t_img_option_v5 = $HTTP_POST_VARS[prize_num].".".$ext;
		}
	}
	$t_img_option .= $HTTP_POST_VARS[img_option5].":".$t_img_option_v5."@";
}
// Ÿɼ
if (empty($HTTP_POST_VARS[prize_view])) { $t_prize_view = "N"; }
else { $t_prize_view = "Y"; }

if (empty($HTTP_POST_VARS[prize_recommand])) { $t_prize_recommand = "N"; }
else { $t_prize_recommand = "Y"; }

if (empty($HTTP_POST_VARS[prize_popular])) { $t_prize_popular = "N"; }
else { $t_prize_popular = "Y"; }

if (empty($HTTP_POST_VARS[prize_new])) { $t_prize_new = "N"; }
else { $t_prize_new = "Y"; }

if (empty($HTTP_POST_VARS[prize_mrecommand])) { $t_prize_mrecommand = "N"; }
else { $t_prize_mrecommand = "Y"; }

if (empty($HTTP_POST_VARS[prize_mpopular])) { $t_prize_mpopular = "N"; }
else { $t_prize_mpopular = "Y"; }

if (empty($HTTP_POST_VARS[prize_mnew])) { $t_prize_mnew = "N"; }
else { $t_prize_mnew = "Y"; }

$t_body = $HTTP_POST_VARS[body];
$remote_ip = $HTTP_REMOTE_ADDR;
$regdate = date("Y-m-d");

//  ۼ
if ($HTTP_POST_VARS[action] == "edit") {
	$query = "UPDATE shop_prize SET ";
	$query .= "category_code='$t_category_code', prize_num='$t_prize_num', prize_sail1='$t_prize_sail1', prize_sail2='$t_prize_sail2', prize_point='$t_prize_point', prize_amount='$t_prize_amount', ";
	$query .= "view_img='$t_view_img', prize_name='$t_prize_name', option1='$t_option1', option2='$t_option2', option3='$t_option3', option_val1='$t_option_val1', option_val2='$t_option_val2', option_val3='$t_option_val3', ";
	$query .= "img_option='$t_img_option', body='$t_body', prize_view='$t_prize_view', prize_recommand='$t_prize_recommand', prize_popular='$t_prize_popular', prize_new='$t_prize_new', prize_mrecommand='$t_prize_mrecommand', ";
	$query .= "prize_mpopular='$t_prize_mpopular', prize_mnew='$t_prize_mnew', remote_ip='$remote_ip', count='0', regdate='$regdate' ";
	$query .= "WHERE prize_num='".$HTTP_POST_VARS[cur_prize_num]."'";
}
elseif ($HTTP_POST_VARS[action] == "add") {
	$query = "UPDATE shop_prize SET pos=pos + 1 WHERE category_code='$t_category_code'";
	if (!mysql_query($query, $db_conn)) {
		echo "ǰ ġ ű Ͽϴ.<br>";
		echo $query;
		exit;
	}
	
	$query = "INSERT INTO shop_prize (category_code, pos, prize_num, prize_sail1, prize_sail2, prize_point, prize_amount, view_img, prize_name, option1, option2, option3, option_val1, option_val2, option_val3, img_option, body, prize_view, prize_recommand, prize_popular, prize_new, prize_mrecommand, prize_mpopular, prize_mnew, remote_ip, count, regdate) ";
	$query .= "VALUES ('$t_category_code', '1', '$t_prize_num', '$t_prize_sail1', '$t_prize_sail2', '$t_prize_point', '$t_prize_amount', ";
	$query .= "'$t_view_img', '$t_prize_name', '$t_option1', '$t_option2', '$t_option3', '$t_option_val1', '$t_option_val2', '$t_option_val3', ";
	$query .= "'$t_img_option', '$t_body', '$t_prize_view', '$t_prize_recommand', '$t_prize_popular', '$t_prize_new', '$t_prize_mrecommand', ";
	$query .= "'$t_prize_mpopular', '$t_prize_mnew', '$remote_ip', '0', '$regdate')";
}

//  
if (!mysql_query($query, $db_conn)) {
	echo " Ȥ DB  ֽϴ.<br>";
	echo $query."<br><br>";
	echo mysql_error();
	exit;
}
else {
	echo "<meta http-equiv='refresh' content='0;url=../prize_list.php?category_code=$t_category_code&page=".$HTTP_POST_VARS[page]."&scale=".$HTTP_POST_VARS[scale]."&search_item=".$HTTP_POST_VARS[search_item]."&search_val=".$HTTP_POST_VARS[search_val]."'>";
}
?>
